aboutsummaryrefslogtreecommitdiff
path: root/nix
diff options
context:
space:
mode:
Diffstat (limited to 'nix')
-rw-r--r--nix/NIX.md16
-rw-r--r--nix/default.nix17
2 files changed, 17 insertions, 16 deletions
diff --git a/nix/NIX.md b/nix/NIX.md
index 047dd82f..e57d5be7 100644
--- a/nix/NIX.md
+++ b/nix/NIX.md
@@ -5,22 +5,22 @@ To import with flakes use
```nix
{
inputs = {
- polymc.url = "github:PolyMC/PolyMC";
+ prismlauncher.url = "github:PrismLauncher/PrismLauncher";
};
...
- nixpkgs.overlays = [ inputs.polymc.overlay ]; ## Within configuration.nix
- environment.systemPackages = with pkgs; [ polymc ]; ##
+ nixpkgs.overlays = [ inputs.prismlauncher.overlay ]; ## Within configuration.nix
+ environment.systemPackages = with pkgs; [ prismlauncher ]; ##
}
```
To import without flakes use channels:
```sh
-nix-channel --add https://github.com/PolyMC/PolyMC/archive/master.tar.gz polymc
-nix-channel --update polymc
-nix-env -iA polymc
+nix-channel --add https://github.com/PrismLauncher/PrismLauncher/archive/master.tar.gz prismlauncher
+nix-channel --update prismlauncher
+nix-env -iA prismlauncher
```
or alternatively you can use
@@ -28,9 +28,9 @@ or alternatively you can use
```nix
{
nixpkgs.overlays = [
- (import (builtins.fetchTarball "https://github.com/PolyMC/PolyMC/archive/develop.tar.gz")).overlay
+ (import (builtins.fetchTarball "https://github.com/PrismLauncher/PrismLauncher/archive/develop.tar.gz")).overlay
];
- environment.systemPackages = with pkgs; [ polymc ];
+ environment.systemPackages = with pkgs; [ prismlauncher ];
}
```
diff --git a/nix/default.nix b/nix/default.nix
index 88b540ab..c8b4f7cc 100644
--- a/nix/default.nix
+++ b/nix/default.nix
@@ -5,6 +5,7 @@
, ninja
, jdk8
, jdk
+, ghc_filesystem
, zlib
, file
, wrapQtAppsHook
@@ -37,19 +38,19 @@ let
libGL
];
# This variable will be passed to Minecraft by PolyMC
gameLibraryPath = libpath + ":/run/opengl-driver/lib";
javaPaths = lib.makeSearchPath "bin/java" ([ jdk jdk8 ] ++ extraJDKs);
in
stdenv.mkDerivation rec {
- pname = "polymc";
+ pname = "prismlauncher";
inherit version;
src = lib.cleanSource self;
- nativeBuildInputs = [ cmake extra-cmake-modules ninja jdk file wrapQtAppsHook ];
+ nativeBuildInputs = [ cmake extra-cmake-modules ninja jdk ghc_filesystem file wrapQtAppsHook ];
buildInputs = [ qtbase quazip zlib ];
dontWrapQtApps = true;
@@ -76,17 +77,17 @@ stdenv.mkDerivation rec {
# we have to check if the system is NixOS before adding stdenv.cc.cc.lib (#923)
postInstall = ''
# xorg.xrandr needed for LWJGL [2.9.2, 3) https://github.com/LWJGL/lwjgl/issues/128
- wrapQtApp $out/bin/polymc \
+ wrapQtApp $out/bin/prismlauncher \
--run '[ -f /etc/NIXOS ] && export LD_LIBRARY_PATH="${stdenv.cc.cc.lib}/lib:$LD_LIBRARY_PATH"' \
--prefix LD_LIBRARY_PATH : ${gameLibraryPath} \
- --prefix POLYMC_JAVA_PATHS : ${javaPaths} \
+ --prefix PRISMLAUNCHER_JAVA_PATHS : ${javaPaths} \
--prefix PATH : ${lib.makeBinPath [ xorg.xrandr ]}
'';
meta = with lib; {
- homepage = "https://polymc.org/";
- downloadPage = "https://polymc.org/download/";
- changelog = "https://github.com/PolyMC/PolyMC/releases";
+ homepage = "https://prismlauncher.org/";
+ downloadPage = "https://prismlauncher.org/download/";
+ changelog = "https://github.com/PrismLauncher/PrismLauncher/releases";
description = "A free, open source launcher for Minecraft";
longDescription = ''
Allows you to have multiple, separate instances of Minecraft (each with
@@ -37,19 +38,19 @@ let
libGL
];
- # This variable will be passed to Minecraft by PolyMC
+ # This variable will be passed to Minecraft by Prism Launcher
gameLibraryPath = libpath + ":/run/opengl-driver/lib";
javaPaths = lib.makeSearchPath "bin/java" ([ jdk jdk8 ] ++ extraJDKs);